==> ejc-middlemeasurement-impl-3.0.0-20221118.082653-234-sources.jar: com/ejianc/business/middlemeasurement/vo/VisaclaimCountersignVO.java <==
package com.ejianc.business.middlemeasurement.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 签证索赔会签单主表
 * 
 * @author generator
 * 
 */
public class VisaclaimCountersignVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编号
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private Long projectDepartmentId; // 项目部id
    private String visaMatters; // 签证事项
    private String visaClaims; // 签证索赔事项
    private List<String> visaClaimsList;//签证索赔事项多选
    private Long agentId; // 经办人
    private String agentName; // 经办人姓名
    private BigDecimal visaclaimAmount; // 签证索赔金额
    private BigDecimal visaclaimConfirmedAmount; //  签证索赔确认金额
    private String visaContentAndAmountCalculationProcess; // 签证内容描述及签证金额计算过程
    private String agentSignature; // 经办人签字
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date agentDate; // 经办人签字日期
    private String opinionEngineer; // 项目总工程师意见
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date engineerDate; // 项目总工程师意见日期
    private String opinionProjectBusinessManager; // 项目商务经理意见
    private String projectBusinessManagerSignature; // 项目商务经理签字
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date projectBusinessManagerDate; // 项目商务经理签字日期
    private String opinionProjectManager; // 项目经理审核意见
    private String projectManagerSignature; // 项目经理签字
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date projectManagerDate; // 项目经理签字日期
    private String opinionBusinessManagementDepartment; // 分/子公司商务管理部意见
    private String businessManagementDepartmentSignature; // 分/子公司商务管理部签字
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date businessManagementDepartmentDate; // 分/子公司商务管理部签字日期
    private String opinionCompanyLegalCounsel; // 分/子公司法律顾问或法务人员意见
    private String companyLegalCounselSignature; // 分/子公司法律顾问或法务人员签字
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date companyLegalCounselDate; // 分/子公司法律顾问或法务人员签字日期
    private String opinionCompanyLeader; // 分/子公司分管领导意见
    private String companyLeaderSignature; // 分/子公司分管领导签字
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date companyLeaderDate; // 分/子公司分管领导签字日期
    private String opinionCompanyGeneralManager; // 分/子公司总经理意见
    private String companyGeneralManagerSignature; // 分/子公司总经理签字
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date companyGeneralManagerDate; // 分/子公司总经理签字日期
    private java.lang.String billStateStr;//单据状态
    private java.lang.String sort;
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public List<String> getVisaClaimsList() {
        return visaClaimsList;
    }

    public void setVisaClaimsList(List<String> visaClaimsList) {
        this.visaClaimsList = visaClaimsList;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public String getVisaMatters() {
        return visaMatters;
    }

    public void setVisaMatters(String visaMatters) {
        this.visaMatters = visaMatters;
    }
    public String getVisaClaims() {
        return visaClaims;
    }

    public void setVisaClaims(String visaClaims) {
        this.visaClaims = visaClaims;
    }
    @ReferSerialTransfer(referCode = "idm-user")
    public Long getAgentId() {
        return agentId;
    }
    @ReferDeserialTransfer
    public void setAgentId(Long agentId) {
        this.agentId = agentId;
    }
    public String getAgentName() {
        return agentName;
    }

    public void setAgentName(String agentName) {
        this.agentName = agentName;
    }
    public BigDecimal getVisaclaimAmount() {
        return visaclaimAmount;
    }

    public void setVisaclaimAmount(BigDecimal visaclaimAmount) {
        this.visaclaimAmount = visaclaimAmount;
    }
    public BigDecimal getVisaclaimConfirmedAmount() {
        return visaclaimConfirmedAmount;
    }

    public void setVisaclaimConfirmedAmount(BigDecimal visaclaimConfirmedAmount) {
        this.visaclaimConfirmedAmount = visaclaimConfirmedAmount;
    }
    public String getVisaContentAndAmountCalculationProcess() {
        return visaContentAndAmountCalculationProcess;
    }

    public void setVisaContentAndAmountCalculationProcess(String visaContentAndAmountCalculationProcess) {
        this.visaContentAndAmountCalculationProcess = visaContentAndAmountCalculationProcess;
    }
    public String getAgentSignature() {
        return agentSignature;
    }

    public void setAgentSignature(String agentSignature) {
        this.agentSignature = agentSignature;
    }
    public Date getAgentDate() {
        return agentDate;
    }

    public void setAgentDate(Date agentDate) {
        this.agentDate = agentDate;
    }
    public String getOpinionEngineer() {
        return opinionEngineer;
    }

    public void setOpinionEngineer(String opinionEngineer) {
        this.opinionEngineer = opinionEngineer;
    }
    public Date getEngineerDate() {
        return engineerDate;
    }

    public void setEngineerDate(Date engineerDate) {
        this.engineerDate = engineerDate;
    }
    public String getOpinionProjectBusinessManager() {
        return opinionProjectBusinessManager;
    }

    public void setOpinionProjectBusinessManager(String opinionProjectBusinessManager) {
        this.opinionProjectBusinessManager = opinionProjectBusinessManager;
    }
    public String getProjectBusinessManagerSignature() {
        return projectBusinessManagerSignature;
    }

    public void setProjectBusinessManagerSignature(String projectBusinessManagerSignature) {
        this.projectBusinessManagerSignature = projectBusinessManagerSignature;
    }
    public Date getProjectBusinessManagerDate() {
        return projectBusinessManagerDate;
    }

    public void setProjectBusinessManagerDate(Date projectBusinessManagerDate) {
        this.projectBusinessManagerDate = projectBusinessManagerDate;
    }
    public String getOpinionProjectManager() {
        return opinionProjectManager;
    }

    public void setOpinionProjectManager(String opinionProjectManager) {
        this.opinionProjectManager = opinionProjectManager;
    }
    public String getProjectManagerSignature() {
        return projectManagerSignature;
    }

    public void setProjectManagerSignature(String projectManagerSignature) {
        this.projectManagerSignature = projectManagerSignature;
    }
    public Date getProjectManagerDate() {
        return projectManagerDate;
    }

    public void setProjectManagerDate(Date projectManagerDate) {
        this.projectManagerDate = projectManagerDate;
    }
    public String getOpinionBusinessManagementDepartment() {
        return opinionBusinessManagementDepartment;
    }

    public void setOpinionBusinessManagementDepartment(String opinionBusinessManagementDepartment) {
        this.opinionBusinessManagementDepartment = opinionBusinessManagementDepartment;
    }
    public String getBusinessManagementDepartmentSignature() {
        return businessManagementDepartmentSignature;
    }

    public void setBusinessManagementDepartmentSignature(String businessManagementDepartmentSignature) {
        this.businessManagementDepartmentSignature = businessManagementDepartmentSignature;
    }
    public Date getBusinessManagementDepartmentDate() {
        return businessManagementDepartmentDate;
    }

    public void setBusinessManagementDepartmentDate(Date businessManagementDepartmentDate) {
        this.businessManagementDepartmentDate = businessManagementDepartmentDate;
    }
    public String getOpinionCompanyLegalCounsel() {
        return opinionCompanyLegalCounsel;
    }

    public void setOpinionCompanyLegalCounsel(String opinionCompanyLegalCounsel) {
        this.opinionCompanyLegalCounsel = opinionCompanyLegalCounsel;
    }
    public String getCompanyLegalCounselSignature() {
        return companyLegalCounselSignature;
    }

    public void setCompanyLegalCounselSignature(String companyLegalCounselSignature) {
        this.companyLegalCounselSignature = companyLegalCounselSignature;
    }
    public Date getCompanyLegalCounselDate() {
        return companyLegalCounselDate;
    }

    public void setCompanyLegalCounselDate(Date companyLegalCounselDate) {
        this.companyLegalCounselDate = companyLegalCounselDate;
    }
    public String getOpinionCompanyLeader() {
        return opinionCompanyLeader;
    }

    public void setOpinionCompanyLeader(String opinionCompanyLeader) {
        this.opinionCompanyLeader = opinionCompanyLeader;
    }
    public String getCompanyLeaderSignature() {
        return companyLeaderSignature;
    }

    public void setCompanyLeaderSignature(String companyLeaderSignature) {
        this.companyLeaderSignature = companyLeaderSignature;
    }
    public Date getCompanyLeaderDate() {
        return companyLeaderDate;
    }

    public void setCompanyLeaderDate(Date companyLeaderDate) {
        this.companyLeaderDate = companyLeaderDate;
    }
    public String getOpinionCompanyGeneralManager() {
        return opinionCompanyGeneralManager;
    }

    public void setOpinionCompanyGeneralManager(String opinionCompanyGeneralManager) {
        this.opinionCompanyGeneralManager = opinionCompanyGeneralManager;
    }
    public String getCompanyGeneralManagerSignature() {
        return companyGeneralManagerSignature;
    }

    public void setCompanyGeneralManagerSignature(String companyGeneralManagerSignature) {
        this.companyGeneralManagerSignature = companyGeneralManagerSignature;
    }
    public Date getCompanyGeneralManagerDate() {
        return companyGeneralManagerDate;
    }

    public void setCompanyGeneralManagerDate(Date companyGeneralManagerDate) {
        this.companyGeneralManagerDate = companyGeneralManagerDate;
    }

    public String getBillStateStr() {
        return billStateStr;
    }

    public void setBillStateStr(String billStateStr) {
        this.billStateStr = billStateStr;
    }

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }
}

==> ejc-middlemeasurement-impl-3.0.0-20230404.070319-438-sources.jar: com/ejianc/business/middlemeasurement/vo/VisaclaimCountersignVO.java <==
package com.ejianc.business.middlemeasurement.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 签证索赔会签单主表
 *
 * @author generator
 *
 */
public class VisaclaimCountersignVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String billCode; // 单据编号
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private Long projectDepartmentId; // 项目部id
    private String visaMatters; // 签证事项
    private String visaClaims; // 签证索赔事项
    private List<String> visaClaimsList;//签证索赔事项多选
    private Long agentId; // 经办人
    private String agentName; // 经办人姓名
    private BigDecimal visaclaimAmount; // 签证索赔金额
    private BigDecimal visaclaimConfirmedAmount; //  签证索赔确认金额
    private String visaContentAndAmountCalculationProcess; // 签证内容描述及签证金额计算过程
    private String agentSignature; // 经办人签字
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date agentDate; // 经办人签字日期
    private String opinionEngineer; // 项目总工程师意见
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date engineerDate; // 项目总工程师意见日期
    private String opinionProjectBusinessManager; // 项目商务经理意见
    private String projectBusinessManagerSignature; // 项目商务经理签字
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date projectBusinessManagerDate; // 项目商务经理签字日期
    private String opinionProjectManager; // 项目经理审核意见
    private String projectManagerSignature; // 项目经理签字
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date projectManagerDate; // 项目经理签字日期
    private String opinionBusinessManagementDepartment; // 分/子公司商务管理部意见
    private String businessManagementDepartmentSignature; // 分/子公司商务管理部签字
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date businessManagementDepartmentDate; // 分/子公司商务管理部签字日期
    private String opinionCompanyLegalCounsel; // 分/子公司法律顾问或法务人员意见
    private String companyLegalCounselSignature; // 分/子公司法律顾问或法务人员签字
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date companyLegalCounselDate; // 分/子公司法律顾问或法务人员签字日期
    private String opinionCompanyLeader; // 分/子公司分管领导意见
    private String companyLeaderSignature; // 分/子公司分管领导签字
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date companyLeaderDate; // 分/子公司分管领导签字日期
    private String opinionCompanyGeneralManager; // 分/子公司总经理意见
    private String companyGeneralManagerSignature; // 分/子公司总经理签字
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date companyGeneralManagerDate; // 分/子公司总经理签字日期
    private java.lang.String billStateStr;//单据状态
    private java.lang.String sort;
    private BigDecimal exVisaclaimAmount; // 报送金额(除税)
    private Integer greatClaimsFlag; // 是否重大索赔事项
    private BigDecimal affirmMnyTax; // 确认金额（含税）
    private BigDecimal affirmMny; // 确认金额（除税）
    private BigDecimal affirmChangeDays; // 确认变更天数
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date affirmTime; // 确认时间
    private BigDecimal nowPaymentMny; // 本期收款金额
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date paymentTime; // 收款时间
    private BigDecimal totalMny; // 已收款金额
    private BigDecimal claimsDays; // 索赔天数

    private List<VisaclaimCountersignDetailVO> visaclaimCountersignDetailEntities = new ArrayList<>(); // 总包签证索赔台账子表

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public List<String> getVisaClaimsList() {
        return visaClaimsList;
    }

    public void setVisaClaimsList(List<String> visaClaimsList) {
        this.visaClaimsList = visaClaimsList;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public String getVisaMatters() {
        return visaMatters;
    }

    public void setVisaMatters(String visaMatters) {
        this.visaMatters = visaMatters;
    }
    public String getVisaClaims() {
        return visaClaims;
    }

    public void setVisaClaims(String visaClaims) {
        this.visaClaims = visaClaims;
    }
    @ReferSerialTransfer(referCode = "idm-user")
    public Long getAgentId() {
        return agentId;
    }
    @ReferDeserialTransfer
    public void setAgentId(Long agentId) {
        this.agentId = agentId;
    }
    public String getAgentName() {
        return agentName;
    }

    public void setAgentName(String agentName) {
        this.agentName = agentName;
    }
    public BigDecimal getVisaclaimAmount() {
        return visaclaimAmount;
    }

    public void setVisaclaimAmount(BigDecimal visaclaimAmount) {
        this.visaclaimAmount = visaclaimAmount;
    }
    public BigDecimal getVisaclaimConfirmedAmount() {
        return visaclaimConfirmedAmount;
    }

    public void setVisaclaimConfirmedAmount(BigDecimal visaclaimConfirmedAmount) {
        this.visaclaimConfirmedAmount = visaclaimConfirmedAmount;
    }
    public String getVisaContentAndAmountCalculationProcess() {
        return visaContentAndAmountCalculationProcess;
    }

    public void setVisaContentAndAmountCalculationProcess(String visaContentAndAmountCalculationProcess) {
        this.visaContentAndAmountCalculationProcess = visaContentAndAmountCalculationProcess;
    }
    public String getAgentSignature() {
        return agentSignature;
    }

    public void setAgentSignature(String agentSignature) {
        this.agentSignature = agentSignature;
    }
    public Date getAgentDate() {
        return agentDate;
    }

    public void setAgentDate(Date agentDate) {
        this.agentDate = agentDate;
    }
    public String getOpinionEngineer() {
        return opinionEngineer;
    }

    public void setOpinionEngineer(String opinionEngineer) {
        this.opinionEngineer = opinionEngineer;
    }
    public Date getEngineerDate() {
        return engineerDate;
    }

    public void setEngineerDate(Date engineerDate) {
        this.engineerDate = engineerDate;
    }
    public String getOpinionProjectBusinessManager() {
        return opinionProjectBusinessManager;
    }

    public void setOpinionProjectBusinessManager(String opinionProjectBusinessManager) {
        this.opinionProjectBusinessManager = opinionProjectBusinessManager;
    }
    public String getProjectBusinessManagerSignature() {
        return projectBusinessManagerSignature;
    }

    public void setProjectBusinessManagerSignature(String projectBusinessManagerSignature) {
        this.projectBusinessManagerSignature = projectBusinessManagerSignature;
    }
    public Date getProjectBusinessManagerDate() {
        return projectBusinessManagerDate;
    }

    public void setProjectBusinessManagerDate(Date projectBusinessManagerDate) {
        this.projectBusinessManagerDate = projectBusinessManagerDate;
    }
    public String getOpinionProjectManager() {
        return opinionProjectManager;
    }

    public void setOpinionProjectManager(String opinionProjectManager) {
        this.opinionProjectManager = opinionProjectManager;
    }
    public String getProjectManagerSignature() {
        return projectManagerSignature;
    }

    public void setProjectManagerSignature(String projectManagerSignature) {
        this.projectManagerSignature = projectManagerSignature;
    }
    public Date getProjectManagerDate() {
        return projectManagerDate;
    }

    public void setProjectManagerDate(Date projectManagerDate) {
        this.projectManagerDate = projectManagerDate;
    }
    public String getOpinionBusinessManagementDepartment() {
        return opinionBusinessManagementDepartment;
    }

    public void setOpinionBusinessManagementDepartment(String opinionBusinessManagementDepartment) {
        this.opinionBusinessManagementDepartment = opinionBusinessManagementDepartment;
    }
    public String getBusinessManagementDepartmentSignature() {
        return businessManagementDepartmentSignature;
    }

    public void setBusinessManagementDepartmentSignature(String businessManagementDepartmentSignature) {
        this.businessManagementDepartmentSignature = businessManagementDepartmentSignature;
    }
    public Date getBusinessManagementDepartmentDate() {
        return businessManagementDepartmentDate;
    }

    public void setBusinessManagementDepartmentDate(Date businessManagementDepartmentDate) {
        this.businessManagementDepartmentDate = businessManagementDepartmentDate;
    }
    public String getOpinionCompanyLegalCounsel() {
        return opinionCompanyLegalCounsel;
    }

    public void setOpinionCompanyLegalCounsel(String opinionCompanyLegalCounsel) {
        this.opinionCompanyLegalCounsel = opinionCompanyLegalCounsel;
    }
    public String getCompanyLegalCounselSignature() {
        return companyLegalCounselSignature;
    }

    public void setCompanyLegalCounselSignature(String companyLegalCounselSignature) {
        this.companyLegalCounselSignature = companyLegalCounselSignature;
    }
    public Date getCompanyLegalCounselDate() {
        return companyLegalCounselDate;
    }

    public void setCompanyLegalCounselDate(Date companyLegalCounselDate) {
        this.companyLegalCounselDate = companyLegalCounselDate;
    }
    public String getOpinionCompanyLeader() {
        return opinionCompanyLeader;
    }

    public void setOpinionCompanyLeader(String opinionCompanyLeader) {
        this.opinionCompanyLeader = opinionCompanyLeader;
    }
    public String getCompanyLeaderSignature() {
        return companyLeaderSignature;
    }

    public void setCompanyLeaderSignature(String companyLeaderSignature) {
        this.companyLeaderSignature = companyLeaderSignature;
    }
    public Date getCompanyLeaderDate() {
        return companyLeaderDate;
    }

    public void setCompanyLeaderDate(Date companyLeaderDate) {
        this.companyLeaderDate = companyLeaderDate;
    }
    public String getOpinionCompanyGeneralManager() {
        return opinionCompanyGeneralManager;
    }

    public void setOpinionCompanyGeneralManager(String opinionCompanyGeneralManager) {
        this.opinionCompanyGeneralManager = opinionCompanyGeneralManager;
    }
    public String getCompanyGeneralManagerSignature() {
        return companyGeneralManagerSignature;
    }

    public void setCompanyGeneralManagerSignature(String companyGeneralManagerSignature) {
        this.companyGeneralManagerSignature = companyGeneralManagerSignature;
    }
    public Date getCompanyGeneralManagerDate() {
        return companyGeneralManagerDate;
    }

    public void setCompanyGeneralManagerDate(Date companyGeneralManagerDate) {
        this.companyGeneralManagerDate = companyGeneralManagerDate;
    }

    public String getBillStateStr() {
        return billStateStr;
    }

    public void setBillStateStr(String billStateStr) {
        this.billStateStr = billStateStr;
    }

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    public BigDecimal getExVisaclaimAmount() {
        return exVisaclaimAmount;
    }

    public void setExVisaclaimAmount(BigDecimal exVisaclaimAmount) {
        this.exVisaclaimAmount = exVisaclaimAmount;
    }

    public Integer getGreatClaimsFlag() {
        return greatClaimsFlag;
    }

    public void setGreatClaimsFlag(Integer greatClaimsFlag) {
        this.greatClaimsFlag = greatClaimsFlag;
    }

    public BigDecimal getAffirmMnyTax() {
        return affirmMnyTax;
    }

    public void setAffirmMnyTax(BigDecimal affirmMnyTax) {
        this.affirmMnyTax = affirmMnyTax;
    }

    public BigDecimal getAffirmMny() {
        return affirmMny;
    }

    public void setAffirmMny(BigDecimal affirmMny) {
        this.affirmMny = affirmMny;
    }

    public BigDecimal getAffirmChangeDays() {
        return affirmChangeDays;
    }

    public void setAffirmChangeDays(BigDecimal affirmChangeDays) {
        this.affirmChangeDays = affirmChangeDays;
    }

    public Date getAffirmTime() {
        return affirmTime;
    }

    public void setAffirmTime(Date affirmTime) {
        this.affirmTime = affirmTime;
    }

    public BigDecimal getNowPaymentMny() {

        return nowPaymentMny;
    }

    public void setNowPaymentMny(BigDecimal nowPaymentMny) {
        this.nowPaymentMny = nowPaymentMny;
    }

    public Date getPaymentTime() {
        return paymentTime;
    }

    public void setPaymentTime(Date paymentTime) {
        this.paymentTime = paymentTime;
    }

    public List<VisaclaimCountersignDetailVO> getVisaclaimCountersignDetailEntities() {
        return visaclaimCountersignDetailEntities;
    }

    public void setVisaclaimCountersignDetailEntities(List<VisaclaimCountersignDetailVO> visaclaimCountersignDetailEntities) {
        this.visaclaimCountersignDetailEntities = visaclaimCountersignDetailEntities;
    }

    public BigDecimal getTotalMny() {
        return totalMny;
    }

    public void setTotalMny(BigDecimal totalMny) {
        this.totalMny = totalMny;
    }

    public BigDecimal getClaimsDays() {
        return claimsDays;
    }

    public void setClaimsDays(BigDecimal claimsDays) {
        this.claimsDays = claimsDays;
    }
}
